# Tools and tips when building napari plugins or: firehose of stuff I wish I knew earlier  

These guides will be more valuable if you are familiar with the Python programming language and the napari software. They are taken from the [January 2022 Testing workshop](https://www.youtube.com/watch?v=IsHYnI8Tbfw&list=PLilvrWT8aLuYID3YZ7KddS5ky2SaH4DKK) video. These guides stand on their own and are summaries of the information in the video. They are listed here in the order they were presented but they do not necessarily build on each other. 
  
* 1: [Virtual environments](./1-virtual-environments) Starts at about minute 49:08.  
* 2: [Deploying your plugin](./2-deploying-your-plugin.md) Starts at about minute 54:00.  
* 3: [Version management](./3-version-management.md) Starts at about timestamp 1:01:00.   
* 4: [Developer tools](./4-developer-tools.md) Starts at about timestamp 1:04:12.  
* 5: [Survey/Q&A](./5-survey.md) Starts at about timestamp 1:15:27.  
